MESSAGE_STATUS_NEW = "NEW"
MESSAGE_STATUS_PENDING = "PENDING"
MESSAGE_STATUS_FAILED = "FAILED"
MESSAGE_STATUS_SUCCEDED = "SUCCEDED"
MESSAGE_STATUS_SKIPPED = "SKIPPED"
MESSAGE_STATUS_PARTIALLY_SKIPPED = "PARTIALLY_SKIPPED"
