"""empty message

Revision ID: b96e7daa1cdb
Revises:
Create Date: 2019-05-17 07:14:08.566157

"""
from alembic import op
import sqlalchemy as sa

import sqlalchemy_utils


# revision identifiers, used by Alembic.
revision = 'b96e7daa1cdb'
down_revision = None
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('message',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('from_', sa.String(length=256), nullable=True),
    sa.Column('to', sqlalchemy_utils.types.scalar_list.ScalarListType(), nullable=True),
    sa.Column('cc', sqlalchemy_utils.types.scalar_list.ScalarListType(), nullable=True),
    sa.Column('bcc', sqlalchemy_utils.types.scalar_list.ScalarListType(), nullable=True),
    sa.Column('subject', sa.String(length=256), nullable=True),
    sa.Column('text', sa.Text(), nullable=True),
    sa.Column('html', sa.Text(), nullable=True),
    sa.Column('attachment', sa.Boolean(), nullable=True),
    sa.Column('tag', sa.String(length=64), nullable=True),
    sa.Column('status', sa.Enum('NEW', 'PENDING', 'FAILED', 'SUCCEDED', 'SKIPPED', 'PARTIALLY_SKIPPED'), nullable=True),
    sa.Column('updated_at', sa.DateTime(), nullable=True),
    sa.Column('created_at', sa.DateTime(), nullable=True),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('unsubscribe',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('email', sa.String(length=256), nullable=True),
    sa.Column('tag', sa.String(length=64), nullable=True),
    sa.Column('created_at', sa.DateTime(), nullable=True),
    sa.PrimaryKeyConstraint('id')
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('unsubscribe')
    op.drop_table('message')
    # ### end Alembic commands ###
